@@ -48,12 +48,13 @@ namespace XSDDiagram
         private Dictionary<string, TabPage> hashtableTabPageByFilename = new Dictionary<string, TabPage>();
 		private string originalTitle = "";
 		private DiagramItem contextualMenuPointedElement = null;
-        private string currentLoadedSchemaFilename = "";
+        //private string currentLoadedSchemaFilename = "";
 
         private TextBox textBoxAnnotation;
         private WebBrowser webBrowserDocumentation;
 		private bool webBrowserSupported = true;
-
+        private string backupUsername = "", backupPassword = "";
+        
 		public MainForm()
 		{
 			InitializeComponent();
@@ -74,6 +75,9 @@ namespace XSDDiagram
 			this.panelDiagram.VirtualSize = new Size(0, 0);
 			this.panelDiagram.DiagramControl.Paint += new PaintEventHandler(DiagramControl_Paint);
 
+            this.schema.RequestCredential += schema_RequestCredential;
+            this.backupUsername = Options.Username;
+            this.backupPassword = Options.Password;
 			if (Options.IsRunningOnMono)
 			{
 				try
@@ -87,6 +91,22 @@ namespace XSDDiagram
 			}
 		}
 
+        bool schema_RequestCredential(string url, string realm, int attemptCount, out string username, out string password)
+        {
+            string label = "The file '" + url + "' requires a username and password.";
+            LoginPromptForm dlg = new LoginPromptForm(label);
+            dlg.Username = backupUsername;
+            dlg.Password = backupPassword;
+            if (dlg.ShowDialog(this) == DialogResult.OK)
+            {
+                backupUsername = username = dlg.Username;
+                backupPassword = password = dlg.Password;
+                return true;
+            }
+            username = password = "";
+            return false;
+        }
+
         /// <summary>
         /// Clean up any resources being used.
         /// </summary>
@@ -147,18 +167,34 @@ namespace XSDDiagram
 				LoadSchema(openFileDialog.FileName);
 		}
 
+        private void openURLToolStripMenuItem_Click(object sender, EventArgs e)
+        {
+            OpenURLForm openURLForm = new OpenURLForm("");
+            if (openURLForm.ShowDialog() == DialogResult.OK)
+                LoadSchema(openURLForm.URL);
+        }
+
 		private void MainForm_DragDrop(object sender, DragEventArgs e)
 		{
-			if (e.Data.GetDataPresent(DataFormats.FileDrop))
-			{
-				string[] files = (string[])e.Data.GetData(DataFormats.FileDrop);
-				LoadSchema(files[0]);
-			}
+            if (e.Data.GetDataPresent("UniformResourceLocator"))
+            {
+                string url = e.Data.GetData(DataFormats.Text, true) as string;
+                if (!string.IsNullOrEmpty(url))
+                    LoadSchema(url.Trim());
+            }
+            else if (e.Data.GetDataPresent(DataFormats.FileDrop))
+            {
+                string[] files = (string[])e.Data.GetData(DataFormats.FileDrop);
+                if(files != null && files.Length > 0)
+                    LoadSchema(files[0]);
+            }
 		}
 
 		private void MainForm_DragEnter(object sender, DragEventArgs e)
 		{
-			if (e.Data.GetDataPresent(DataFormats.FileDrop))
+            if (e.Data.GetDataPresent(DataFormats.FileDrop)
+                || e.Data.GetDataPresent("UniformResourceLocator")
+                )
 				e.Effect = DragDropEffects.Move;
 			else
 				e.Effect = DragDropEffects.None;
@@ -180,7 +216,17 @@ namespace XSDDiagram
                     exporter.Export(outputFilename, g1, new DiagramAlertHandler(SaveAlert));
                     g1.Dispose();
 				}
-				catch (Exception ex)
+                catch (System.ArgumentException ex)
+                {
+                    MessageBox.Show("You have reach the system limit.\r\nPlease remove some element from the diagram to make it smaller.");
+                    System.Diagnostics.Trace.WriteLine(ex.ToString());
+                }
+                catch (System.Runtime.InteropServices.ExternalException ex)
+                {
+                    MessageBox.Show("You have reach the system limit.\r\nPlease remove some element from the diagram to make it smaller.");
+                    System.Diagnostics.Trace.WriteLine(ex.ToString());
+                }
+                catch (Exception ex)
 				{
                     MessageBox.Show(ex.Message);
 					System.Diagnostics.Trace.WriteLine(ex.ToString());
@@ -342,7 +388,7 @@ namespace XSDDiagram
 			}
 			this.tabControlView.ResumeLayout();
 
-            currentLoadedSchemaFilename = schemaFilename;
+            //currentLoadedSchemaFilename = schemaFilename;
 		}
 
 		void DiagramControl_MouseClick(object sender, MouseEventArgs e)
@@ -522,7 +568,8 @@ namespace XSDDiagram
                 foreach (XSDAttribute attribute in listAttributes)
                 {
                     string s = "";
-                    if (attribute.Tag.simpleType != null && attribute.Tag.simpleType.Item is XMLSchema.restriction)
+                    //dgis fix github issue 2 (attribute.Tag == null ???)
+                    if (attribute.Tag != null && attribute.Tag.simpleType != null && attribute.Tag.simpleType.Item is XMLSchema.restriction)
                     {
                         XMLSchema.restriction r = attribute.Tag.simpleType.Item as XMLSchema.restriction;
                         if (r.Items != null)
@@ -662,8 +709,9 @@ namespace XSDDiagram
 			string type = "";
 			if (attribute.@ref != null)
 			{
-				object o = this.schema.AttributesByName[QualifiedNameToFullName("attribute", attribute.@ref)];
-				if (o is XSDAttribute)
+                object o = null;
+                this.schema.AttributesByName.TryGetValue(QualifiedNameToFullName("attribute", attribute.@ref), out o);
+                if (o is XSDAttribute)
 				{
 					XSDAttribute xsdAttributeInstance = o as XSDAttribute;
 					ParseAttribute(nameSpace, listAttributes, xsdAttributeInstance.Tag, isRestriction);
@@ -734,8 +782,9 @@ namespace XSDDiagram
 		{
 			if (attributeGroup is XMLSchema.attributeGroupRef && attributeGroup.@ref != null)
 			{
-				object o = this.schema.AttributesByName[QualifiedNameToFullName("attributeGroup", attributeGroup.@ref)];
-				if (o is XSDAttributeGroup)
+                object o = null;
+                this.schema.AttributesByName.TryGetValue(QualifiedNameToFullName("attributeGroup", attributeGroup.@ref), out o);
+                if (o is XSDAttributeGroup)
 				{
 					XSDAttributeGroup xsdAttributeGroup = o as XSDAttributeGroup;
 					XMLSchema.attributeGroup attributeGroupInstance = xsdAttributeGroup.Tag;
@@ -830,7 +879,7 @@ namespace XSDDiagram
 							{
 								XMLSchema.facet facet = restriction.Items[i] as XMLSchema.facet;
 								if (facet != null)
-									this.listViewEnumerate.Items.Add(facet.value);
+                                    this.listViewEnumerate.Items.Add(facet.value).Tag = facet;
 							}
 						}
 
@@ -945,6 +994,18 @@ namespace XSDDiagram
 			}
 		}
 
+        private void listViewEnumerate_SelectedIndexChanged(object sender, EventArgs e)
+		{
+            if (this.listViewEnumerate.SelectedItems.Count > 0)
+			{
+				XMLSchema.facet facet = this.listViewEnumerate.SelectedItems[0].Tag as XMLSchema.facet;
+				if (facet != null && facet.annotation != null)
+					ShowDocumentation(facet.annotation);
+				else
+					ShowDocumentation(null);
+			}
+		}
+
 		private void toolStripComboBoxZoom_SelectedIndexChanged(object sender, EventArgs e)
 		{
 			try
@@ -1111,8 +1172,8 @@ namespace XSDDiagram
 				XSDObject xsdObject;
                 if (this.schema.ElementsByName.TryGetValue(this.contextualMenuPointedElement.FullName, out xsdObject) && xsdObject != null)
 				{
-					TabPage tabPage = this.hashtableTabPageByFilename[xsdObject.Filename];
-					if (tabPage != null)
+                    TabPage tabPage = null;
+                    if (this.hashtableTabPageByFilename.TryGetValue(xsdObject.Filename, out tabPage) && tabPage != null)
 						this.tabControlView.SelectedTab = tabPage;
 				}
 			}
@@ -1558,8 +1619,8 @@ namespace XSDDiagram
                     settings.ValidationFlags = XmlSchemaValidationFlags.ReportValidationWarnings |
                                                 XmlSchemaValidationFlags.ProcessIdentityConstraints |
                                                 XmlSchemaValidationFlags.ProcessInlineSchema |
-                                                XmlSchemaValidationFlags.ProcessSchemaLocation |
-                                                XmlSchemaValidationFlags.AllowXmlAttributes;
+                                                XmlSchemaValidationFlags.ProcessSchemaLocation
+												; //| XmlSchemaValidationFlags.AllowXmlAttributes;
                     //settings.Schemas.Add("http://www.collada.org/2005/11/COLLADASchema", currentLoadedSchemaFilename);
                     //settings.Schemas.Add(null, currentLoadedSchemaFilename); // = sc;
                     List<string> schemas = new List<string>(schema.XsdFilenames);
@@ -1621,6 +1682,16 @@ namespace XSDDiagram
             validateXMLFileToolStripMenuItem.Enabled = (schema != null && schema.XsdFilenames.Count != 0);
         }
 
+		private void MainForm_KeyUp(object sender, KeyEventArgs e)
+		{
+			if (e.Control && (e.KeyCode == Keys.D0 || e.KeyCode == Keys.NumPad0))
+			{
+				this.toolStripComboBoxZoom.SelectedIndex = 8;
+			}
+		}
+
+
+
 		//void DiagramControl_MouseMove(object sender, MouseEventArgs e)
 		//{
 		//System.Diagnostics.Trace.WriteLine("toolTipDiagramElement_Popup");
